==> openshift-model-operatorhub-4.11.0-sources.jar: annotations/io/fabric8/openshift/api/model/operatorhub/v1/OperatorGroupSpecFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.lang.Boolean;
import java.util.Map;

public interface OperatorGroupSpecFluent<A extends OperatorGroupSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildSelector instead.
 * @return The buildable object.
 */
@Deprecated public LabelSelector getSelector();
    public LabelSelector buildSelector();
    public A withSelector(LabelSelector selector);
    public Boolean hasSelector();
    public OperatorGroupSpecFluent.SelectorNested<A> withNewSelector();
    public OperatorGroupSpecFluent.SelectorNested<A> withNewSelectorLike(LabelSelector item);
    public OperatorGroupSpecFluent.SelectorNested<A> editSelector();
    public OperatorGroupSpecFluent.SelectorNested<A> editOrNewSelector();
    public OperatorGroupSpecFluent.SelectorNested<A> editOrNewSelectorLike(LabelSelector item);
    public String getServiceAccountName();
    public A withServiceAccountName(String serviceAccountName);
    public Boolean hasServiceAccountName();
    public A withNewServiceAccountName(String arg1);
    public A withNewServiceAccountName(StringBuilder arg1);
    public A withNewServiceAccountName(StringBuffer arg1);
    public Boolean isStaticProvidedAPIs();
    public A withStaticProvidedAPIs(Boolean staticProvidedAPIs);
    public Boolean hasStaticProvidedAPIs();
    public A withNewStaticProvidedAPIs(String arg1);
    public A withNewStaticProvidedAPIs(boolean arg1);
    public A addToTargetNamespaces(int index,String item);
    public A setToTargetNamespaces(int index,String item);
    public A addToTargetNamespaces(String... items);
    public A addAllToTargetNamespaces(Collection<String> items);
    public A removeFromTargetNamespaces(String... items);
    public A removeAllFromTargetNamespaces(Collection<String> items);
    public List<String> getTargetNamespaces();
    public String getTargetNamespace(int index);
    public String getFirstTargetNamespace();
    public String getLastTargetNamespace();
    public String getMatchingTargetNamespace(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public Boolean hasMatchingTargetNamespace(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withTargetNamespaces(List<String> targetNamespaces);
    public A withTargetNamespaces(String... targetNamespaces);
    public Boolean hasTargetNamespaces();
    public A addNewTargetNamespace(String arg1);
    public A addNewTargetNamespace(StringBuilder arg1);
    public A addNewTargetNamespace(StringBuffer arg1);

    public interface SelectorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,LabelSelectorFluent<OperatorGroupSpecFluent.SelectorNested<N>>{

        
    public N and();    public N endSelector();
}


}

==> openshift-model-operatorhub-5.0.0-sources.jar: annotations/io/fabric8/openshift/api/model/operatorhub/v1/OperatorGroupSpecFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.lang.Boolean;
import java.util.Map;

public interface OperatorGroupSpecFluent<A extends OperatorGroupSpecFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildSelector instead.
 * @return The buildable object.
 */
@Deprecated public LabelSelector getSelector();
    public LabelSelector buildSelector();
    public A withSelector(LabelSelector selector);
    public Boolean hasSelector();
    public OperatorGroupSpecFluent.SelectorNested<A> withNewSelector();
    public OperatorGroupSpecFluent.SelectorNested<A> withNewSelectorLike(LabelSelector item);
    public OperatorGroupSpecFluent.SelectorNested<A> editSelector();
    public OperatorGroupSpecFluent.SelectorNested<A> editOrNewSelector();
    public OperatorGroupSpecFluent.SelectorNested<A> editOrNewSelectorLike(LabelSelector item);
    public String getServiceAccountName();
    public A withServiceAccountName(String serviceAccountName);
    public Boolean hasServiceAccountName();
    public A withNewServiceAccountName(String arg1);
    public A withNewServiceAccountName(StringBuilder arg1);
    public A withNewServiceAccountName(StringBuffer arg1);
    public Boolean isStaticProvidedAPIs();
    public A withStaticProvidedAPIs(Boolean staticProvidedAPIs);
    public Boolean hasStaticProvidedAPIs();
    public A withNewStaticProvidedAPIs(String arg1);
    public A withNewStaticProvidedAPIs(boolean arg1);
    public A addToTargetNamespaces(int index,String item);
    public A setToTargetNamespaces(int index,String item);
    public A addToTargetNamespaces(String... items);
    public A addAllToTargetNamespaces(Collection<String> items);
    public A removeFromTargetNamespaces(String... items);
    public A removeAllFromTargetNamespaces(Collection<String> items);
    public List<String> getTargetNamespaces();
    public String getTargetNamespace(int index);
    public String getFirstTargetNamespace();
    public String getLastTargetNamespace();
    public String getMatchingTargetNamespace(Predicate<String> predicate);
    public Boolean hasMatchingTargetNamespace(Predicate<String> predicate);
    public A withTargetNamespaces(List<String> targetNamespaces);
    public A withTargetNamespaces(String... targetNamespaces);
    public Boolean hasTargetNamespaces();
    public A addNewTargetNamespace(String arg1);
    public A addNewTargetNamespace(StringBuilder arg1);
    public A addNewTargetNamespace(StringBuffer arg1);
    public interface SelectorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,LabelSelectorFluent<OperatorGroupSpecFluent.SelectorNested<N>> {

        public N and();
        public N endSelector();    }


}
